Module: RSpec::Support::Retry
- Included in:
- RackApp
- Defined in:
- lib/hanami/devtools/integration/retry.rb
Overview
Implement retry logic.
It may happen that the setup of a test is slower then expected. Instead of let it to blow up, we can retry after a few seconds.